@@ -3,9 +3,10 @@ from abc import ABC, abstractmethod
 
 class ModelConfig:
 
-    def __init__(self, id, name, version, extra, model_package, model_class, bins):
+    def __init__(self, id, name, version, extra, model_package, model_class, bins, storage_type='s3'):
         self.id = id
         self.name = name
+        self.storage_type = storage_type
         self.extra = extra
         self.version = version
         self.model_package = model_package
@@ -20,7 +21,8 @@ class ModelConfig:
             'extra': self.extra,
             'model_package': self.model_package,
             'model_class': self.model_class,
-            'bins': self.bins
+            'bins': self.bins,
+            'storage_type': self.storage_type
         }
 
     @staticmethod
@@ -33,7 +35,21 @@ class ModelConfig:
             extra=config_dict['extra'],
             model_package=config_dict['model_package'],
             model_class=config_dict['model_class'],
-            bins=config_dict['bins']
+            bins=config_dict['bins'],
+            storage_type=config_dict.get('storage_type', 's3')
+        )
+
+    @staticmethod
+    def default_config():
+        return ModelConfig(
+            id=None,
+            name=None,
+            version=None,
+            extra={},
+            model_package=None,
+            model_class=None,
+            bins={},
+            storage_type='s3'
         )
 
     def __str__(self):
