@@ -1,4 +1,4 @@
-from spt_datascience import BaseModel, ModelConfig
+from spt_datascience.datascience.models.base_model import BaseModel, ModelConfig
 
 
 class EstimatorModel(BaseModel):
@@ -16,4 +16,4 @@ class EstimatorModel(BaseModel):
         )
 
     def model_name(self) -> str:
-        return 'mlflow_sklrean'
\ No newline at end of file
+        return 'mlflow_sklearn'
\ No newline at end of file
